@@ -304,7 +304,7 @@ class RedisDecimal(RedisString):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
             check_types(self.value, (int, float, decimal.Decimal))
-            self.value = float(self.value)
+            self.value = str(self.value)
         return super().clean()
 
     def deserialize_value(self, value, redis_root):
@@ -468,7 +468,7 @@ class RedisRoot:
                 if allowed:
                     if django_field.name in ['id', 'pk']:
                         django_field_name = 'django_id'
-                        redis_field = RedisNumber(null=False)
+                        redis_field = RedisNumber(null=True)
                     else:
                         redis_field = django_field_to_redis_field(django_field, redis_root, save_related_models,
                                                                   exclude_fields)
@@ -526,13 +526,13 @@ class RedisRoot:
             return redis_field
 
         def django_field_params_to_redis_field_params(django_field, redis_root, save_related_models, exclude_fields):
-            allowed_params = ['null', 'default', 'choices', 'remote_field']
+            allowed_params = ['default', 'choices', 'remote_field']
             allowed_redis_params = {}
             for django_field_param_name in django_field.__dict__.keys():
                 redis_field_param_name = django_field_param_name
                 if django_field_param_name in allowed_params:
                     value = getattr(django_field, django_field_param_name)
-                    if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH]:
+                    if value in [django_models.NOT_PROVIDED, django_models.Empty, django_models.BLANK_CHOICE_DASH, None]:
                         value = None
                     if django_field_param_name == 'choices':
                         real_value = {}
@@ -544,13 +544,11 @@ class RedisRoot:
                         value = real_value
                         allowed_redis_params[redis_field_param_name] = value
                     elif django_field_param_name == 'remote_field':
-                        redis_field_param_name = 'redis_model'
+                        redis_field_param_name = 'model'
                         if value is not None:
                             value = value.model
                             if value is not None:
-                                print(value)
                                 value = redis_root.get_or_create_redis_model_from_django_model(value)
-                                print(value)
                                 if value is not None:
                                     allowed_redis_params[redis_field_param_name] = value
                                     allowed_redis_params['save_related_models'] = save_related_models
@@ -865,8 +863,11 @@ class RedisRoot:
         filter_field_name, filter_type = filter_param, 'exact'
         if '__' in filter_param:
             filter_param_split = filter_param.split('__')
-            fields_to_filter = filter_param_split[:-1]
-            filter_type = filter_param_split[-1]
+            if filter_param_split[-1] in ['exact', 'iexact', 'contains', 'icontains', 'in', 'gt', 'gte', 'lt', 'lte', 'startswith', 'istartswith', 'endswith', 'iendswith', 'range']:
+                fields_to_filter = filter_param_split[:-1]
+                filter_type = filter_param_split[-1]
+            else:
+                fields_to_filter = filter_param_split
         else:
             fields_to_filter = [filter_field_name]
         return fields_to_filter, filter_type
@@ -1151,15 +1152,17 @@ class RedisModel:
         fields = self.__model_data__['fields']
         fields = dict(fields)
         instance_key = f'{redis_root.prefix}:{name}:{self.id.value}'
+        deserialized_fields = {}
         cleaned_fields = {}
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
+                    deserialized_fields[field_name] = field.value
                     cleaned_value = field.clean()
                     cleaned_fields[field_name] = cleaned_value
                 except BaseException as ex:
                     raise Exception(f'{ex} ({name} -> {field_name})')
-        return instance_key, cleaned_fields
+        return instance_key, deserialized_fields
     
     def get_model_ttl(self):
         ttl = None
